import java.io.*;

/**
 * A client with error recovery.
 * This client assumes that the server detects bad input from the client.
 * 
 * @author Uno Holmer
 * @version 2008-01-28
 */
public class Client {
    private Server server;

    public Client(Server server) {
        this.server = server;
    }

    void run() {
        BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
        int failures = 0;
        boolean success = false;
        do {
            try {
                 System.out.print("Input value: ");
                 String digits = input.readLine();
                 Integer i = new Integer(digits.trim());
                 System.out.println(server.compute( i ));
                 success = true;
            }
            catch (NumberFormatException e) {
                System.out.println(e + "\nNon digit input");
                break;
            }
            catch (IOException e) {
                System.out.println(e + "\nI give up!");
                break;
            }
            catch(ServerException e) {
                System.out.println(e);
                ++failures;
            }
        } while (!success && failures < 3);
    }
}
